@@ -1,5 +1,4 @@
-from django import forms
-from django.utils.translation import ugettext_lazy as _
+from __future__ import unicode_literals
 
 from ..forms import CreditCardPaymentFormWithName
 from .. import get_credit_card_issuer
